<!---
I am the base class from which switchbasedmigration and
sqlbasedmigration (at the moment) are derived from, providing the core
framework for running individual minor updates in a controlled manner,
regardless of how they are actually managed.  I should, in most cases,
also be the superclass of any custom migration script types.
------------------------------------------------------------------------
$Id: basemigration.cfc 2317 2007-06-02 05:47:55Z barneyb $

Copyright 2007 Barney Boisvert (bboisvert@gmail.com).

Licensed under the Apache License, Version 2.0 (the "License"); you may
not use this file except in compliance with the License. You may obtain
a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
--->
<cfcomponent output="false" abstract="true">

	<cffunction name="init" access="public" output="false" returntype="abstractmigration">
		<cfargument name="dsn" type="string" required="true" />
		<cfset variables.my.dsn = dsn />
		<cfreturn this />
	</cffunction>
	
	
	
	<cffunction name="migrate" access="public" output="false" returntype="void">
		<cfargument name="currentMinor" type="numeric" required="true" />
		<cfset var maxMinor = getMaxMinorVersion() />
		<cfset var minor = "" />
		<cfloop from="#currentMinor + 1#" to="#maxMinor#" index="minor">
			<cftransaction>
				<cfset doMinorVersion(minor) />
				<cfset setMinorVersion(minor) />
			</cftransaction>
		</cfloop>
	</cffunction>
	

	
	<cffunction name="getMaxMinorVersion" access="public" output="false" returntype="numeric"
		hint="I am called get the maximum minor version provided by this migration.">
		<cfthrow type="AbstractMethodException"
			message="The 'getMaxMinorVersion' method MUST be overridden in subclasses." />
	</cffunction>
	
	
	
	<cffunction name="doMinorVersion" access="public" output="false" returntype="void"
		hint="I am called to perform the given minor version upgrade.  It is safe to assume that the schema is currently at (minorVersion - 1) when this method is invoked.">
		<cfargument name="minorVersion" type="numeric" required="true" />
		<cfthrow type="AbstractMethodException"
			message="The 'doMinorVersion' method MUST be overridden in subclasses." />
	</cffunction>
	
	
	
	<cffunction name="setMinorVersion" access="private" output="false" returntype="void">
		<cfargument name="minorVersion" type="numeric" required="true" />
		<cfquery datasource="#variables.my.dsn#" name="">
			update schema_version set
				minor_version = <cfqueryparam cfsqltype="cf_sql_integer" value="#minorVersion#" />
		</cfquery>
	</cffunction>

<cfoutput></cfoutput>
</cfcomponent>